import { revalidatePath } from "next/cache";
import JobCard from "./_jobcard/JobCard";

interface JobPosting {
  title: string;
  logo: string;
  company: string;
  location: string;
  type: string;
  description: string;
  link: string;
  skills: {
    react: boolean;
    python: boolean;
    golang: boolean;
    svelte: boolean;
    nextjs: boolean;
    typescript: boolean;
    tailwind: boolean;
  };
}

async function fetchJobs(): Promise<JobPosting[]> {
  const response = await fetch("https://jobs-api.rannes.dev/itjobbank", {
    cache: "no-store",
  });
  if (!response.ok) {
    throw new Error("Failed to fetch jobs");
  }

  revalidatePath("/");
  return response.json();
}

export default async function ITJobbank() {
  const jobs = await fetchJobs();
  return (
    <>
      <h2 className="text-4xl my-4">IT Jobbank</h2>
      <p className="text-xl">
        It jobbank do not optimize their images for the web, and like to use
        images and videos in their job postings. This is heavily impacting the
        user experience of this part of the site, and I am working on a
        solution.
      </p>
      {jobs.map((job, i) => (
        <JobCard key={i} job={job} />
      ))}
    </>
  );
}
